@@ -1,11 +1,12 @@
 package Pithub::PullRequests;
 our $AUTHORITY = 'cpan:PLU';
-our $VERSION = '0.01034';
+our $VERSION = '0.01036';
 # ABSTRACT: Github v3 Pull Requests API
 
 use Moo;
-use Carp qw(croak);
+use Carp qw( croak );
 use Pithub::PullRequests::Comments;
+use Pithub::PullRequests::Reviewers;
 extends 'Pithub::Base';
 
 
@@ -14,6 +15,11 @@ sub comments {
 }
 
 
+sub reviewers {
+    return shift->_create_instance('Pithub::PullRequests::Reviewers', @_);
+}
+
+
 sub commits {
     my ( $self, %args ) = @_;
     croak 'Missing key in parameters: pull_request_id' unless $args{pull_request_id};
@@ -123,7 +129,7 @@ Pithub::PullRequests - Github v3 Pull Requests API
 
 =head1 VERSION
 
-version 0.01034
+version 0.01036
 
 =head1 METHODS
 
@@ -131,6 +137,10 @@ version 0.01034
 
 Provides access to L<Pithub::PullRequests::Comments>.
 
+=head2 reviewers
+
+Provides access to L<Pithub::PullRequests::Reviewers>.
+
 =head2 commits
 
 =over
@@ -315,7 +325,7 @@ Johannes Plunien <plu@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2011 by Johannes Plunien.
+This software is copyright (c) 2011-2019 by Johannes Plunien.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
