@@ -1,10 +1,10 @@
 package Pithub::Repos::Watching;
 our $AUTHORITY = 'cpan:PLU';
-our $VERSION = '0.01035';
+our $VERSION = '0.01036';
 # ABSTRACT: Github v3 Repo Watching API
 
 use Moo;
-use Carp qw(croak);
+use Carp ();
 extends 'Pithub::Base';
 
 
@@ -82,7 +82,7 @@ Pithub::Repos::Watching - Github v3 Repo Watching API
 
 =head1 VERSION
 
-version 0.01035
+version 0.01036
 
 =head1 METHODS
 
